<?php

class Productimport extends Tools_Plugins_Abstract
{

    /**
     * Product import db table
     */
    const PLUGIN_PRODUCTIMPORT_IMPORT_TABLE = 'plugin_productimport_import';

    /**
     * process one time products limit
     */
    const IMPORT_PRODUCTS_LIMIT = 5;

    /**
     * Path to sample file import
     */
    const SAMPLE_FILE_IMPORT_DIR = 'productimport/web/sample/';

    /**
     * Sample file import name
     */
    const SAMPLE_FILE_IMPORT_NAME = 'example.csv';
    /**
     * Default delimiter
     *
     * @var array
     */
    private $_csvSettings = array(
        'delimiter' => ','
    );

    /**
     * Minimum required import fields
     *
     * @var array
     */
    private $_minimumRequiredFields = array(
        'sku',
        'mpn',
        'name',
        'brand',
        'weight',
        'photo',
        'short_description',
        'full_description',
        'price',
        'tags',
        'tax_class',
        'base_price',
        'inventory',
        'free_shipping',
        'related'
    );

    /**
     * config helper
     *
     * @var null
     */
    private $_configHelper = null;

    /**
     *
     * Shopping tags dbTable
     *
     * @var null
     *
     */
    private $_tagsDbTable = null;

    /**
     * Cache helper
     *
     * @var null
     */
    private $_cacheHelper = null;

    /**
     * Related product dbTable
     *
     * @var null
     */
    private $_relatedTable = null;

    /**
     * Product import dbTable
     *
     * @var null
     */
    private $_productImportDbTable = null;

    /**
     * Toaster layout
     *
     * @var
     */
    private $_layout = null;

    /**
     * Default column types for import
     *
     * @var array
     */
    private $_importFieldTypes = array(
        'id' => '`id` INT(11) NOT NULL AUTO_INCREMENT',
        'status' => "`status` ENUM('0', '1') DEFAULT '0'",
        'status_related' => "`status_related` ENUM('0', '1') DEFAULT '0'",
        'sku' => '`sku` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'mpn' => '`mpn` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'name' => '`name`TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'brand' => '`brand` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'weight' => '`weight` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'photo' => '`photo` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'short_description' => '`short_description` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'full_description' => '`full_description` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'price' => '`price` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'tags' => '`tags` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'tax_class' => "`tax_class` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL",
        'base_price' => '`base_price` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'inventory' => '`inventory` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'free_shipping' => "`free_shipping` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL",
        'attribute' => 'TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'container' => 'TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL',
        'related' => '`related` TEXT CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL'
    );

    /**
     * init
     */
    protected function _init()
    {
        $this->_configHelper = Zend_Controller_Action_HelperBroker::getStaticHelper('config');
        $this->_tagsDbTable = new Models_DbTable_Tag();
        $this->_relatedTable = new Models_DbTable_ProductRelated();
        $this->_filterAttributesDbTable = new Filtering_DbTables_Attributes();
        $this->_filterMapper = Filtering_Mappers_Eav::getInstance();
        $this->_productImportDbTable = new Productimport_Models_Dbtables_ProductimportDbtable();
        $this->_cacheHelper = Zend_Controller_Action_HelperBroker::getStaticHelper('cache');
        $this->_layout = new Zend_Layout();
        $this->_layout->setLayoutPath(Zend_Layout::getMvcInstance()->getLayoutPath());

        if (($scriptPaths = Zend_Layout::getMvcInstance()->getView()->getScriptPaths()) !== false) {
            $this->_view->setScriptPath($scriptPaths);
        }
        $this->_view->addScriptPath(__DIR__ . '/system/views/');
    }

    /**
     * Render product import configuration panel
     */
    public function renderCsvAction()
    {
        if (Tools_Security_Acl::isAllowed(Tools_Security_Acl::RESOURCE_PLUGINS)) {
            $this->_view->translator = $this->_translator;
            $templateMapper = Application_Model_Mappers_TemplateMapper::getInstance();
            $productTemplateList = $templateMapper->findByType('typeproduct');
            $this->_view->templateList = $productTemplateList;
            $this->_layout->content = $this->_view->render('productimport.phtml');
            echo $this->_layout->render();
        }
    }

    /**
     *
     * Upload csv with products and store all information in database
     *
     */
    public function uploadCsvAction()
    {
        if (Tools_Security_Acl::isAllowed(Tools_Security_Acl::RESOURCE_PLUGINS)) {
            $uploader = new Zend_File_Transfer_Adapter_Http();
            $csvInfo = $uploader->getFileInfo();
            $templateName = $this->_request->getParam('productTemplates');
            $photoFolder = $this->_request->getParam('photoFolder');
            $updateExistProducts = $this->_request->getParam('updateProducts');
            $updateConfig = $this->_request->getParam('checkedOption');
            $useMpnAsSku = $this->_request->getParam('useMpnAsSku');
            $useProductNameAsSku = $this->_request->getParam('useProductNameAsSku');
            $updateConfig = $this->_prepareUpdateOptions($updateConfig);
            $this->_sessionHelper->productImportConfig = array(
                'useMpnAsSku' => $useMpnAsSku,
                'useProductNameAsSku' => $useProductNameAsSku,
                'updateExistingProducts' => $updateExistProducts,
                'templateName' => $templateName,
                'photoFolder' => $photoFolder,
                'updateConfig' => $updateConfig
            );
            if (!$uploader->isValid()) {
                $this->_responseHelper->fail('');
            }
            $csvData = $this->_putCsvToDatabase($csvInfo);
            if ($csvData['error'] === 0) {
                $this->_responseHelper->success(array('productsQuantity' => $csvData['productsQuantity']));
            } else {
                $this->_responseHelper->fail($csvData['errorMessage']);
            }
        }
    }

    /**
     * Prepare product options config
     *
     * @param $checkedOptions
     * @return array
     */
    private function _prepareUpdateOptions($checkedOptions)
    {
        $resultArray = array();
        if ($checkedOptions !== '') {
            $resultArray = explode(',', $checkedOptions);
        }
        return $resultArray;
    }

    /**
     *
     * Storing fresh imported csv to database
     *
     * @param $csvInfo
     * @return array
     *
     */
    private function _putCsvToDatabase($csvInfo)
    {
        $csvFile = fopen($csvInfo['file']['tmp_name'], 'r');
        $translator = Zend_Registry::get('Zend_Translate');
        $productDbTable = new Productimport_Models_Dbtables_ProductimportDbtable();
        if ($csvFile !== false) {
            $assignHeaders = false;
            $importProductsData = array();
            $excludeHeadersKeys = array();
            $ordersHeaders = array();
            $columnNames = array();
            while (($productData = fgetcsv($csvFile, $this->_csvSettings['delimiter'])) !== false) {
                if (!$assignHeaders) {
                    $assignHeaders = true;
                    $ordersHeaders = array_flip(array_map('strtolower', $productData));
                    $requiredFields = array_diff_key(array_flip($this->_minimumRequiredFields), $ordersHeaders);
                    if (!empty($requiredFields)) {
                        $errorMessage = '';
                        foreach ($requiredFields as $fieldMissed => $key) {
                            $errorMessage .= $fieldMissed . '<br />';
                        }
                        fclose($csvFile);
                        return array(
                            'error' => 1,
                            'errorMessage' => $translator->translate(
                                'Required fields missed'
                            ) . '<br />' . $errorMessage
                        );
                    }
                    $deleteImportTableSql = "DROP TABLE IF EXISTS " . self::PLUGIN_PRODUCTIMPORT_IMPORT_TABLE;
                    $stmt = $productDbTable->getAdapter()->prepare($deleteImportTableSql);
                    $stmt->execute();
                    $sql = "CREATE TABLE IF NOT EXISTS " . self::PLUGIN_PRODUCTIMPORT_IMPORT_TABLE . " (";
                    $sql .= $this->_importFieldTypes['id'] . ',';
                    $sql .= $this->_importFieldTypes['status'] . ',';
                    $sql .= $this->_importFieldTypes['status_related'] . ',';
                    foreach ($ordersHeaders as $columnName => $columnKey) {
                        if (array_key_exists($columnName, $this->_importFieldTypes)) {
                            $sql .= ' ' . $this->_importFieldTypes[$columnName] . ',';
                        } elseif (preg_match('~attribute_~', $columnName)) {
                            $sql .= ' `' . $columnName . '` ' . $this->_importFieldTypes['attribute'] . ',';
                        } else {
                            $excludeHeadersKeys[$columnKey] = $columnKey;
                            unset($ordersHeaders[$columnName]);
                        }
                    }
                    $sql .= ' PRIMARY KEY (`id`)) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;';
                    $stmt = $productDbTable->getAdapter()->prepare($sql);
                    $stmt->execute();
                    $columnNames = implode(array_flip($ordersHeaders), ', ');
                    continue;
                }

                $productData = array_diff_key($productData, $excludeHeadersKeys);
                $importProductsData = array_merge($importProductsData, $productData);
            }
            fclose($csvFile);
            $productsQuantity = 0;
            if (!empty($importProductsData)) {
                $whereStm = substr(str_repeat('?,', count($ordersHeaders)), 0, -1);
                $productsQuantity = count($importProductsData) / count($ordersHeaders);
                $values = implode(
                    ',',
                    array_fill(0, $productsQuantity, '(' . $whereStm . ')')
                );
                $importProductsStmt = $productDbTable->getAdapter()
                    ->prepare(
                        'INSERT INTO ' . self::PLUGIN_PRODUCTIMPORT_IMPORT_TABLE . ' (' . $columnNames . ') VALUES ' . $values . ''
                    );
                $importProductsStmt->execute($importProductsData);
            }
            return array('error' => 0, 'productsQuantity' => $productsQuantity);

        } else {
            return array(
                'error' => 1,
                'errorMessage' => $translator->translate('File error')
            );
        }
    }

    /**
     * Importing products (without related products)
     */
    public function importProductsAction()
    {
        if ($this->_request->isPost() && Tools_Security_Acl::isAllowed(Tools_Security_Acl::RESOURCE_PLUGINS)
            && isset($this->_sessionHelper->productImportConfig)
        ) {
            $importConfig = $this->_sessionHelper->productImportConfig;
            $where = $this->_productImportDbTable->getAdapter()->quoteInto('status <> ?', '1');
            $select = $this->_productImportDbTable->getAdapter()->select()->from(
                self::PLUGIN_PRODUCTIMPORT_IMPORT_TABLE
            )
                ->where($where)
                ->limit(self::IMPORT_PRODUCTS_LIMIT);
            $productsData = $this->_productImportDbTable->getAdapter()->fetchAll($select);
            $productMapper = Models_Mapper_ProductMapper::getInstance();
            $checkFieldInDatabase = 'sku';
            if ($importConfig['useMpnAsSku'] === 'true') {
                $checkFieldInDatabase = 'mpn';
            }
            if ($importConfig['useProductNameAsSku'] === 'true') {
                $checkFieldInDatabase = 'name';
            }
            $templateName = $importConfig['templateName'];
            $photoFolder = $importConfig['photoFolder'];
            $updateExistingProducts = $importConfig['updateExistingProducts'];
            $updateConfig = $importConfig['updateConfig'];
            $validatorSku = new Zend_Validate_Db_NoRecordExists(array(
                'table' => 'shopping_product',
                'field' => $checkFieldInDatabase
            ));
            $importedProducts = array();

            if (!empty($productsData)) {
                foreach ($productsData as $prodData) {
                    array_push($importedProducts, $prodData['id']);
                    $sku = filter_var(trim($prodData[$checkFieldInDatabase]), FILTER_SANITIZE_STRING);
                    $mpn = filter_var(trim($prodData['mpn']), FILTER_SANITIZE_STRING);
                    $brandName = filter_var(trim($prodData['brand']), FILTER_SANITIZE_STRING);
                    $productName = filter_var(trim($prodData['name']), FILTER_SANITIZE_STRING);
                    $price = $prodData['price'];
                    $weight = $prodData['weight'];
                    $taxClass = filter_var($prodData['tax_class'], FILTER_SANITIZE_NUMBER_INT);
                    $inventory = filter_var($prodData['inventory'], FILTER_SANITIZE_NUMBER_INT);
                    $freeShipping = filter_var($prodData['free_shipping'], FILTER_SANITIZE_NUMBER_INT);
                    $fullDescription = $prodData['full_description'];
                    $shortDescription = $prodData['short_description'];
                    $tags = $this->_prepareTag($prodData['tags']);
                    if ($sku === '' || $brandName === '' || $price === '' || $prodData['photo'] === '') {
                        continue;
                    }
                    if (preg_match('~(http|https):\/\/~', $prodData['photo'])) {
                        $photoName = $prodData['photo'];
                    } else {
                        $photoName = $this->_preparePhoto($prodData['photo'], $photoFolder, $sku);
                    }
                    $productModel = new Models_Model_Product();
                    $attributes = preg_grep('~attribute_~', array_keys($prodData));
                    if (!$validatorSku->isValid($sku)) {
                        if ($updateExistingProducts === 'true' && !empty($updateConfig)) {
                            $where = $productMapper->getDbTable()->getAdapter()->quoteInto(
                                'p.' . $checkFieldInDatabase . ' = ?',
                                $sku
                            );
                            $products = $productMapper->fetchAll($where);
                            if (!empty($products)) {
                                $product = $products[0];
                                if (in_array('name', $updateConfig)) {
                                    $product->setName($productName);
                                }
                                $product->setSku($sku);
                                if (in_array('mpn', $updateConfig)) {
                                    $product->setMpn($mpn);
                                }
                                if (in_array('photo', $updateConfig)) {
                                    $product->setPhoto($photoName);
                                }
                                if (in_array('weight', $updateConfig)) {
                                    $product->setWeight($weight);
                                }
                                if (in_array('price', $updateConfig)) {
                                    $product->setPrice($price);
                                }
                                if (in_array('brand', $updateConfig)) {
                                    $product->setBrand($brandName);
                                }
                                if (in_array('shortDescription', $updateConfig)) {
                                    $product->setShortDescription($shortDescription);
                                }
                                if (in_array('fullDescription', $updateConfig)) {
                                    $product->setFullDescription($fullDescription);
                                }
                                if (in_array('tags', $updateConfig) && !empty($tags)) {
                                    $product->setTags($tags);
                                }
                                $productMapper->save($product);
                                if (!empty($attributes)) {
                                    $this->_createUpdateAttributes(
                                        array_flip($attributes),
                                        $prodData,
                                        $product->getId(),
                                        $tags
                                    );
                                }
                            }

                        }
                        continue;
                    } else {
                        $productModel->setId(null);
                        $productModel->setSku($sku);
                    }
                    $productModel->setPhoto($photoName);
                    $productModel->setBrand($brandName);
                    $productModel->setPrice($price);
                    $productModel->setName($productName);
                    $productModel->setFullDescription($fullDescription);
                    $productModel->setShortDescription($shortDescription);
                    $productModel->setWeight($weight);
                    $productModel->setMpn($mpn);
                    $productModel->setEnabled(1);
                    if (!empty($tags)) {
                        $productModel->setTags($tags);
                    }
                    $productModel->setTaxClass($taxClass);
                    $productModel->setInventory($inventory);
                    $productModel->setFreeShipping($freeShipping);
                    $productModel->setPageTemplate($templateName);
                    $productMapper->save($productModel);
                    $this->_createUpdateAttributes(array_flip($attributes), $prodData, $productModel->getId(), $tags);
                }
            } else {
                $this->_responseHelper->fail('');
            }
            $where = $this->_productImportDbTable->getAdapter()->quoteInto('id IN (?)', $importedProducts);
            $this->_productImportDbTable->getAdapter()->update(
                'plugin_productimport_import',
                array('status' => 1),
                $where
            );
            $this->_cacheHelper->clean(null, null, array('productlist', 'productListWidget', 'productindex'));
            if (count($productsData) === self::IMPORT_PRODUCTS_LIMIT) {
                $this->_responseHelper->success('');
            } else {
                $this->_responseHelper->fail('');
            }
        }
    }

    /**
     * Import related products
     */
    public function importRelatedProductsAction()
    {
        if ($this->_request->isPost() && Tools_Security_Acl::isAllowed(Tools_Security_Acl::RESOURCE_PLUGINS)
            && isset($this->_sessionHelper->productImportConfig)
        ) {
            $where = $this->_productImportDbTable->getAdapter()->quoteInto('status_related <> ?', '1');
            $select = $this->_productImportDbTable->getAdapter()->select()->from(
                self::PLUGIN_PRODUCTIMPORT_IMPORT_TABLE,
                array('id', 'sku', 'related')
            )
                ->where($where)
                ->limit(self::IMPORT_PRODUCTS_LIMIT);
            $relatedProductsData = $this->_productImportDbTable->getAdapter()->fetchAssoc($select);
            $importedRelatedProducts = array();
            if (!empty($relatedProductsData)) {
                foreach ($relatedProductsData as $related) {
                    array_push($importedRelatedProducts, $related['id']);
                    $relatedProductsSku = array_filter(explode(',', $related['related']));
                    if (!empty($relatedProductsSku)) {
                        $relatedProductsSku[] = $related['sku'];
                        $where = $this->_productImportDbTable->getAdapter()->quoteInto(
                            'sku IN (?)',
                            $relatedProductsSku
                        );
                        $select = $this->_productImportDbTable->getAdapter()->select()->from(
                            'shopping_product',
                            array('sku', 'id')
                        )
                            ->where($where);
                        $relatedProductsIds = $this->_productImportDbTable->getAdapter()->fetchAssoc($select);
                        if (!empty($relatedProductsIds) && isset($relatedProductsIds[$related['sku']])) {
                            $productId = $relatedProductsIds[$related['sku']]['id'];
                            unset($relatedProductsIds[$related['sku']]);
                            $where = $this->_relatedTable->getAdapter()->quoteInto('product_id = ?', $productId);
                            $this->_relatedTable->delete($where);
                            foreach ($relatedProductsIds as $sku => $prodInfo) {
                                $this->_relatedTable->insert(
                                    array(
                                        'product_id' => $productId,
                                        'related_id' => intval($prodInfo['id'])
                                    )
                                );
                            }
                        }
                    }
                }
            }
            $where = $this->_productImportDbTable->getAdapter()->quoteInto('id IN (?)', $importedRelatedProducts);
            $this->_productImportDbTable->getAdapter()->update(
                'plugin_productimport_import',
                array('status_related' => 1),
                $where
            );
            if (count($relatedProductsData) === self::IMPORT_PRODUCTS_LIMIT) {
                $this->_responseHelper->success('');
            } else {
                $this->_responseHelper->fail('');
            }
        }
    }

    /**
     * Creating or updating product attributes
     *
     * @param array $attributes
     * @param array $prodData array(id, status, status_related, name, sku, mpn, short_description
     *              full_description, price, tags, brand, weight, tax_class, base_price, inventory
     *              free_shipping, related)
     * @param int $productId Product id
     * @param array $tags
     *
     */
    private function _createUpdateAttributes($attributes, $prodData, $productId, $tags = array())
    {
        foreach ($attributes as $attrName => $attr) {
            $attributeName = str_replace('attribute_', '', $attrName);
            $where = $this->_filterAttributesDbTable->getAdapter()->quoteInto('name = ?', $attributeName);
            $select = $this->_filterAttributesDbTable->getAdapter()->select()->from(
                'shopping_filtering_attributes'
            )->where($where);
            $attributeExist = $this->_filterAttributesDbTable->getAdapter()->fetchAll($select);
            if (empty($attributeExist)) {
                $attrId = $this->_filterAttributesDbTable->insert(
                    array('name' => $attributeName, 'label' => $attributeName)
                );
            } else {
                $attrId = $attributeExist[0]['id'];
            }
            $this->_filterMapper->saveEavContainer($productId, $attrId, $prodData[$attrName]);
            if (!empty($tags)) {
                $where = $this->_filterAttributesDbTable->getAdapter()->quoteInto('attribute_id = ?', $attrId);
                $select = $this->_filterAttributesDbTable->getAdapter()->select()->from(
                    'shopping_filtering_tags_has_attributes'
                )->where($where);
                $existingTags = $this->_filterAttributesDbTable->getAdapter()->fetchAssoc($select);
                foreach ($tags as $tag) {
                    if (!isset($existingTags[$tag['id']])) {
                        $data = array(
                            'tag_id' => $tag['id'],
                            'attribute_id' => $attrId
                        );
                        $this->_filterAttributesDbTable->getAdapter()->insert(
                            'shopping_filtering_tags_has_attributes',
                            $data
                        );
                    }
                }
            }
        }
    }

    /**
     * Preparing tags
     *
     * @param string $tagNames (FirstTag,SecondTag)
     * @return array tags (array(0 => array(id, name)))
     *
     */
    private function _prepareTag($tagNames)
    {
        $tags = array_unique(array_filter(explode(',', $tagNames)));
        $tagsResult = array();
        if (!empty($tags)) {
            foreach ($tags as $tagName) {
                $where = $this->_tagsDbTable->getAdapter()->quoteInto('name = ?', $tagName);
                $tagExist = $this->_tagsDbTable->getAdapter()->fetchAll(
                    $this->_tagsDbTable->select()->from('shopping_tags')->where($where)
                );
                if (!empty($tagExist)) {
                    $tagsResult[] = array('id' => $tagExist[0]['id'], 'name' => $tagName);
                } else {
                    $tagId = $this->_tagsDbTable->insert(array('name' => $tagName));
                    $tagsResult[] = array('id' => $tagId, 'name' => $tagName);
                }
            }
        }
        return $tagsResult;
    }

    /**
     * Preparing product photo name
     *
     * @param string $photoName Product photo name
     * @param string $photoFolder Image folder
     * @param string $sku  Product unique sku
     * @return string Image name with path
     *
     */
    private function _preparePhoto($photoName, $photoFolder, $sku)
    {
        $photo = '';
        if ($photoFolder === '' && $photoName === '') {
            $photo = 'products' . DIRECTORY_SEPARATOR . $sku . '.jpg';
        } elseif ($photoFolder === '' && $photoName !== '') {
            if (preg_match('~\/~', $photoName)) {
                $photoName = $this->_multibytePathinfo($photoName, 'withFolder');
            } else {
                $photoName = $this->_multibytePathinfo($photoName, 'withoutFolder');
            }
            if ($photoName !== '') {
                $photo = $photoName;
            }
        } elseif ($photoFolder !== '' && $photoName === '') {
            $photo = $photoFolder . DIRECTORY_SEPARATOR . $sku . '.jpg';
        } elseif ($photoFolder !== '' && $photoName !== '') {
            $photoName = $this->_multibytePathinfo($photoName, 'withoutFolder');
            if ($photoName !== '') {
                $photo = $photoFolder . DIRECTORY_SEPARATOR . $photoName;
            }
        }
        return $photo;
    }

    /**
     * Creating image path
     *
     * @param string $filePath Image path
     * @param string $useFolder (withoutFolder or withFolder)
     * @return string Image path
     *
     */
    private function _multibytePathinfo($filePath, $useFolder)
    {
        $imageName = '';
        if (preg_match('%^(.*?)[\\\\/]*(([^/\\\\]*?)(\.([^\.\\\\/]+?)|))[\\\\/\.]*$%im', $filePath, $result)) {
            if ($useFolder === 'withoutFolder') {
                $imageName = $result[2];
            }
            if ($useFolder === 'withFolder') {
                if ($result[2]) {
                    $imageName = $result[2];
                    $dirName = basename($result[1]);
                    $imageName = $dirName . DIRECTORY_SEPARATOR . $imageName;
                }
            }
        }
        return $imageName;
    }


    /**
     * Download sample file with import products data
     */
    public function getSampleImportDataAction()
    {
        if (Tools_Security_Acl::isAllowed(Tools_Security_Acl::RESOURCE_PLUGINS)) {
            $pluginPath = Tools_Plugins_Tools::getPluginsPath();
            $filePath = $pluginPath . self::SAMPLE_FILE_IMPORT_DIR . self::SAMPLE_FILE_IMPORT_NAME;
            $response = Zend_Controller_Front::getInstance()->getResponse();
            $response->setHeader(
                'Content-Disposition',
                'attachment; filename=' . self::SAMPLE_FILE_IMPORT_NAME
            )
                ->setHeader('Content-type', 'application/force-download');
            readfile($filePath);
            $response->sendResponse();
            exit;
        }
    }
}

